@@ -5,6 +5,7 @@ from .utils import (
     create_dependency_package_basename,
 )
 from .server_api import (
+    RequestTypes,
     ServerAPI,
 )
 
@@ -32,6 +33,7 @@ from ._api import (
     set_timeout,
     get_max_retries,
     set_max_retries,
+    is_service_user,
     get_site_id,
     set_site_id,
     get_client_version,
@@ -44,6 +46,7 @@ from ._api import (
     get_server_version,
     get_server_version_tuple,
     get_users,
+    get_user_by_name,
     get_user,
     raw_post,
     raw_put,
@@ -60,7 +63,9 @@ from ._api import (
     update_event,
     dispatch_event,
     enroll_event_job,
+    download_file_to_stream,
     download_file,
+    upload_file_from_stream,
     upload_file,
     trigger_server_restart,
     query_graphql,
@@ -98,8 +103,12 @@ from ._api import (
     get_default_anatomy_preset_name,
     get_project_anatomy_preset,
     get_build_in_anatomy_preset,
+    get_project_root_overrides,
     get_project_roots_by_site,
+    get_project_root_overrides_by_site_id,
     get_project_roots_for_site,
+    get_project_roots_by_site_id,
+    get_project_roots_by_platform,
     get_addon_settings_schema,
     get_addon_site_settings_schema,
     get_addon_studio_settings,
@@ -170,6 +179,8 @@ from ._api import (
     get_representations,
     get_representation_by_id,
     get_representation_by_name,
+    get_representations_hierarchy,
+    get_representation_hierarchy,
     get_representations_parents,
     get_representation_parents,
     get_repre_ids_by_context_filters,
@@ -219,6 +230,7 @@ __all__ = (
     "slugify_string",
     "create_dependency_package_basename",
 
+    "RequestTypes",
     "ServerAPI",
 
     "GlobalServerAPI",
@@ -244,6 +256,7 @@ __all__ = (
     "set_timeout",
     "get_max_retries",
     "set_max_retries",
+    "is_service_user",
     "get_site_id",
     "set_site_id",
     "get_client_version",
@@ -256,6 +269,7 @@ __all__ = (
     "get_server_version",
     "get_server_version_tuple",
     "get_users",
+    "get_user_by_name",
     "get_user",
     "raw_post",
     "raw_put",
@@ -272,7 +286,9 @@ __all__ = (
     "update_event",
     "dispatch_event",
     "enroll_event_job",
+    "download_file_to_stream",
     "download_file",
+    "upload_file_from_stream",
     "upload_file",
     "trigger_server_restart",
     "query_graphql",
@@ -310,8 +326,12 @@ __all__ = (
     "get_default_anatomy_preset_name",
     "get_project_anatomy_preset",
     "get_build_in_anatomy_preset",
+    "get_project_root_overrides",
     "get_project_roots_by_site",
+    "get_project_root_overrides_by_site_id",
     "get_project_roots_for_site",
+    "get_project_roots_by_site_id",
+    "get_project_roots_by_platform",
     "get_addon_settings_schema",
     "get_addon_site_settings_schema",
     "get_addon_studio_settings",
@@ -382,6 +402,8 @@ __all__ = (
     "get_representations",
     "get_representation_by_id",
     "get_representation_by_name",
+    "get_representations_hierarchy",
+    "get_representation_hierarchy",
     "get_representations_parents",
     "get_representation_parents",
     "get_repre_ids_by_context_filters",
